//@line 36 "/builds/slave/tracemonkey-linux-nightly/build/browser/locales/en-US/firefox-l10n.js"

//@line 38 "/builds/slave/tracemonkey-linux-nightly/build/browser/locales/en-US/firefox-l10n.js"

pref("general.useragent.locale", "en-US");
